@@ -2,3 +2,5 @@ from .types import *
 from .other_utils import *
 from .math_utils import *
 from .string_utils import *
+from .time_utils import *
+from . import string_utils
